.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.fw
-------------------

.. automodule:: reahl.web.fw

Basics of defining an application
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

ReahlWebApplication
"""""""""""""""""""

.. autoclass:: ReahlWebApplication
   :members:

Region
""""""

.. autoclass:: Region
   :members:

Widget
""""""

.. autoclass:: Widget
   :members:

WidgetFactory
"""""""""""""

.. autoclass:: WidgetFactory
   :members:

Bookmark
""""""""

.. autoclass:: Bookmark
   :members:

EventHandler
""""""""""""

.. autoclass:: EventHandler
   :members:

Transition
""""""""""

.. autoclass:: Transition
   :members:

View
""""

.. autoclass:: View
   :members:

ViewFactory
"""""""""""

.. autoclass:: ViewFactory
   :members:

UrlBoundView
""""""""""""

.. autoclass:: UrlBoundView
   :members:

ParameterisedPath
"""""""""""""""""

.. autoclass:: ParameterisedPath
   :members:

RegexPath
"""""""""

.. autoclass:: RegexPath
   :members:


SubResources
^^^^^^^^^^^^

SubResource
"""""""""""

.. autoclass:: SubResource
   :members:

RemoteMethod
""""""""""""

.. autoclass:: RemoteMethod
   :members:

CheckedRemoteMethod
"""""""""""""""""""

.. autoclass:: CheckedRemoteMethod
   :members:

EventChannel
""""""""""""

.. autoclass:: EventChannel
   :members:

MethodResult
""""""""""""

.. autoclass:: MethodResult
   :members:

RedirectAfterPost
"""""""""""""""""

.. autoclass:: RedirectAfterPost
   :members:

JsonResult
""""""""""

.. autoclass:: JsonResult
   :members:

WidgetResult
""""""""""""

.. autoclass:: WidgetResult
   :members:


Controlling flow via Detours and Redirects
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

ViewPreCondition
""""""""""""""""

.. autoclass:: ViewPreCondition
   :members:

Redirect
""""""""

.. autoclass:: Redirect
   :members:

Detour
""""""

.. autoclass:: Detour
   :members:

Return
""""""

.. autoclass:: Return
   :members:


Utility
^^^^^^^

Url
"""
.. autoclass:: Url
   :members: 

Exceptions
^^^^^^^^^^

CannotCreate
""""""""""""

.. autoexception:: CannotCreate

ValidationException
"""""""""""""""""""

.. autoexception:: ValidationException



